@@ -6,12 +6,27 @@ function (behavior,phaseX,v1,v2) {
   tm<-table(dzone,phaseX) 
   
   ctbl<-cbind(tm[,v1],tm[,v2])
+  ctbl<-as.table(ctbl)
   
+  
+  num<-ctbl[4]
+  nl<-c("There are", as.character(num),"values below the median line in the intervention.")
+  colnames (ctbl)<-c("Baselene", "Intervention")
+  
+  writeLines(" ")
+  writeLines("Note: Intervention TRUE values below the median line are desired.")
+  cat(sprintf(nl),"\n")
+  
+  writeLines(" ")
   print(ctbl)
+  
+  writeLines(" ")
   print(prop.table(ctbl,1)*100)
+  writeLines(" ")
   print(prop.table(ctbl,2)*100)
-  c1<-chisq.test(ctbl,correct=FALSE)
-  f1<-fisher.test(ctbl,alternative = "two.sided")
+  writeLines(" ")
+  c1<-chisq.test(ctbl,simulate.p.value = TRUE)
+  f1<-fisher.test(ctbl,alternative = "two.sided",conf.int = FALSE)
   print(c1)
   print(f1)
   #graphics.off()
